@@ -5,9 +5,9 @@ use warnings;
 use Acme::CPANModulesUtil::Misc;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-06-30'; # DATE
+our $DATE = '2024-07-01'; # DATE
 our $DIST = 'Acme-CPANModules-SmartMatch'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 my $text = <<'MARKDOWN';
 **About smart match**
@@ -64,26 +64,41 @@ still use it.
 **Modules**
 
 However, if you still miss smart matching, some modules have been written to
-give you somewhat similar feature.
+give you the same/similar feature.
 
 <pm:match::smart> (by TOBYINK, first released 2013, pure-perl) gives you a
 similar behaviour to perl's own `~~`. It can be used as the `|M|` operator or as
 the `match()` function.
 
+<pm:Switch::Back> (by DCONWAY, first released in June 2024, pure-perl). Written
+by one of the designers of Perl 6, Switch::Back offers roughly the same feature
+set as the old `switch` and smartmatching. Although there's no longer `~~`, just
+the `smartmatch()` function. So basically what <pm:match::smart> offers, but 11
+years later.
+
 <pm:match::simple> (by TOBYINK which is also the author of `match::smart`, first
 released in 2013, in the same distribution as `match::smart`, available in XS as
-well as pure-perl) offers a simplified version of smart matching. Still it has 8
-kinds of behaviors depending on the /right/ hand side.
+well as pure-perl) offers a simplified version of smart matching. It has 8 kinds
+of behaviors depending only on the /right/ hand side.
 
 Also see <pm:match::simple::sugar> which gives you `when`, `then`, and `numeric`
 for use in a `for()` statement as a switch/use alternative.
 
-<pm:Switch::Right> (by DCONWAY, first released in June 2024, pure-perl). Written
-by one of the designers of Perl 6, Switch::Right offers a simplified (or
-reimagined) `switch` and smartmatching by simplifying the rules from 23 to just
-6, though the rules still depend on a mix of left and right operands. Since the
-module is new and has no reverse dependencies on CPAN yet, we still need to wait
-and see if the ruleset is a good and practical compromise.
+<pm:Switch::Right> (by DCONWAY, first released in June 2024, pure-perl). Also
+like TOBYINK with his duo of `match::smart` and `match::simple`, DCONWAY offers
+a companion to `Switch::Back`, a simplified/reimagined version of `switch` and
+smartmatching by simplifying the rules from 23 to just 6. The rules still depend
+on a mix of left and right operands.
+
+
+**Personal take**
+
+I personally haven't used `switch` all that much in Perl, though I used to use
+quite a bit of smartmatching in the 2010s, mostly the `SCALAR ~~
+ARRAY-OF-SCALARS` variant. I won't use `match::smart` or `Switch::Back` in any
+practical code, but which between `match::simple` and `Switch::Right` are the
+best compromise? I guess we'll have to see. In the mean time, see my benchmark
+in <pm:Bencher::ScenarioBundle::SmartMatch>.
 
 
 **Other modules**
@@ -117,7 +132,7 @@ Acme::CPANModules::SmartMatch - List of modules to do smart matching
 
 =head1 VERSION
 
-This document describes version 0.004 of Acme::CPANModules::SmartMatch (from Perl distribution Acme-CPANModules-SmartMatch), released on 2024-06-30.
+This document describes version 0.005 of Acme::CPANModules::SmartMatch (from Perl distribution Acme-CPANModules-SmartMatch), released on 2024-07-01.
 
 =head1 DESCRIPTION
 
@@ -173,26 +188,40 @@ still use it.
 B<Modules>
 
 However, if you still miss smart matching, some modules have been written to
-give you somewhat similar feature.
+give you the same/similar feature.
 
 L<match::smart> (by TOBYINK, first released 2013, pure-perl) gives you a
 similar behaviour to perl's own C<~~>. It can be used as the C<|M|> operator or as
 the C<match()> function.
 
+L<Switch::Back> (by DCONWAY, first released in June 2024, pure-perl). Written
+by one of the designers of Perl 6, Switch::Back offers roughly the same feature
+set as the old C<switch> and smartmatching. Although there's no longer C<~~>, just
+the C<smartmatch()> function. So basically what L<match::smart> offers, but 11
+years later.
+
 L<match::simple> (by TOBYINK which is also the author of C<match::smart>, first
 released in 2013, in the same distribution as C<match::smart>, available in XS as
-well as pure-perl) offers a simplified version of smart matching. Still it has 8
-kinds of behaviors depending on the /right/ hand side.
+well as pure-perl) offers a simplified version of smart matching. It has 8 kinds
+of behaviors depending only on the /right/ hand side.
 
 Also see L<match::simple::sugar> which gives you C<when>, C<then>, and C<numeric>
 for use in a C<for()> statement as a switch/use alternative.
 
-L<Switch::Right> (by DCONWAY, first released in June 2024, pure-perl). Written
-by one of the designers of Perl 6, Switch::Right offers a simplified (or
-reimagined) C<switch> and smartmatching by simplifying the rules from 23 to just
-6, though the rules still depend on a mix of left and right operands. Since the
-module is new and has no reverse dependencies on CPAN yet, we still need to wait
-and see if the ruleset is a good and practical compromise.
+L<Switch::Right> (by DCONWAY, first released in June 2024, pure-perl). Also
+like TOBYINK with his duo of C<match::smart> and C<match::simple>, DCONWAY offers
+a companion to C<Switch::Back>, a simplified/reimagined version of C<switch> and
+smartmatching by simplifying the rules from 23 to just 6. The rules still depend
+on a mix of left and right operands.
+
+B<Personal take>
+
+I personally haven't used C<switch> all that much in Perl, though I used to use
+quite a bit of smartmatching in the 2010s, mostly the C<SCALAR ~~
+ARRAY-OF-SCALARS> variant. I won't use C<match::smart> or C<Switch::Back> in any
+practical code, but which between C<match::simple> and C<Switch::Right> are the
+best compromise? I guess we'll have to see. In the mean time, see my benchmark
+in L<Bencher::ScenarioBundle::SmartMatch>.
 
 B<Other modules>
 
@@ -206,14 +235,26 @@ a smart match replacement.
 
 =item L<match::smart>
 
+Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
+
+=item L<Switch::Back>
+
 =item L<match::simple>
 
+Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
+
 =item L<match::simple::sugar>
 
+Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
+
 =item L<Switch::Right>
 
+=item L<Bencher::ScenarioBundle::SmartMatch>
+
 =item L<Smart::Match>
 
+Author: L<LEONT|https://metacpan.org/author/LEONT>
+
 =back
 
 =head1 FAQ
